SizeBuilder constructor
const
SizeBuilder({})
Constructs a SizeBuilder widget.
The mobileBuilder function is called when the device type is mobile and the orientation is portrait.
The tabletBuilder function is called when the device type is tablet and the orientation is portrait.
The desktopBuilder function is called for all other cases.
Implementation
const SizeBuilder({
Key? key,
required this.mobileBuilder,
required this.tabletBuilder,
required this.desktopBuilder,
}) : super(key: key);